.. meta::
   :description: How-to guides for using Hydra and hydra-zen.

.. _hydra-zen-how-to:

How-To Guides
=============

These how-to guides are here to help hydra-zen users who are wondering: "How do I ___?". 
Our guides help you learn by having you do; they provide simple steps towards concrete 
objectives.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   how_to/configuring_experiments
   how_to/configure_hydra
   how_to/partial_config
   how_to/beartype
   how_to/using_scikit_learn
   how_to/pytorch_lightning
